
# Slot: neurodata_type_inc


Used alongside neurodata_type_def to indicate inheritance, naming, and mixins

URI: [nwb_schema_language:neurodata_type_inc](https://w3id.org/p2p_ld/nwb-schema-language/neurodata_type_inc)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Dataset](Dataset.md)
 * [Group](Group.md)
